@@ -1,7 +1,5 @@
 use super::MotorPort;
-#[cfg(target_os = "linux")]
-use crate::wait;
-use crate::{Attribute, Device, Driver, Ev3Error, Ev3Result};
+use crate::{wait, Attribute, Device, Driver, Ev3Error, Ev3Result};
 use std::time::Duration;
 
 /// EV3/NXT large servo motor
