@@ -110,7 +110,7 @@ macro_rules! tacho_motor {
 
         /// Returns the number of tacho counts in the full travel of the motor.
         ///
-        /// When combined with the count_per_m atribute,
+        /// When combined with the count_per_m attribute,
         /// you can use this value to calculate the maximum travel distance of the motor.
         /// (linear motors only)
         pub fn get_full_travel_count(&self) -> Ev3Result<i32> {
@@ -620,7 +620,6 @@ macro_rules! tacho_motor {
         /// # Ok(())
         /// # }
         /// ```
-        #[cfg(target_os = "linux")]
         pub fn wait<F>(&self, cond: F, timeout: Option<Duration>) -> bool
         where
             F: Fn() -> bool,
@@ -651,7 +650,6 @@ macro_rules! tacho_motor {
         /// # Ok(())
         /// # }
         /// ```
-        #[cfg(target_os = "linux")]
         pub fn wait_while(&self, state: &str, timeout: Option<Duration>) -> bool {
             let cond = || {
                 self.get_state()
@@ -684,7 +682,6 @@ macro_rules! tacho_motor {
         /// # Ok(())
         /// # }
         /// ```
-        #[cfg(target_os = "linux")]
         pub fn wait_until(&self, state: &str, timeout: Option<Duration>) -> bool {
             let cond = || {
                 self.get_state()
@@ -697,7 +694,7 @@ macro_rules! tacho_motor {
 
         /// Wait until the motor is not moving or the timeout is reached.
         ///
-        /// This is euqal to `wait_while(STATE_RUNNING, timeout)`.
+        /// This is equal to `wait_while(STATE_RUNNING, timeout)`.
         /// If the `timeout` is `None` it will wait an infinite time.
         ///
         /// # Example
@@ -718,7 +715,6 @@ macro_rules! tacho_motor {
         /// # Ok(())
         /// # }
         /// ```
-        #[cfg(target_os = "linux")]
         pub fn wait_until_not_moving(&self, timeout: Option<Duration>) -> bool {
             self.wait_while(Self::STATE_RUNNING, timeout)
         }
